# Cascades

*This is not an officially supported Google product*

Python library which enables complex compositions of language models such as
scratchpads, chain of thought, tool use, selection-inference, and more.

Implemented as a universal trace-based probabilistic programming library
embedded in Python.
